[lld] r197753 - Fix some typos of 'extension'.

Joey Gouly joey.gouly at gmail.com
Thu Dec 19 15:52:00 PST 2013


Author: joey
Date: Thu Dec 19 17:52:00 2013
New Revision: 197753

URL: http://llvm.org/viewvc/llvm-project?rev=197753&view=rev
Log:
Fix some typos of 'extension'.

Modified:
    lld/trunk/include/lld/ReaderWriter/Reader.h

Modified: lld/trunk/include/lld/ReaderWriter/Reader.h
URL: http://llvm.org/viewvc/llvm-project/lld/trunk/include/lld/ReaderWriter/Reader.h?rev=197753&r1=197752&r2=197753&view=diff
==============================================================================
--- lld/trunk/include/lld/ReaderWriter/Reader.h (original)
+++ lld/trunk/include/lld/ReaderWriter/Reader.h Thu Dec 19 17:52:00 2013
@@ -41,9 +41,9 @@ public:
   /// Sniffs the file to determine if this Reader can parse it.
   /// The method is called with:
   /// 1) the file_magic enumeration returned by identify_magic()
   /// 2) the file extenstion (e.g. ".obj")
   /// 3) the whole file content buffer if the above is not enough. 
-  virtual bool canParse(file_magic magic, StringRef fileExtention, 
+  virtual bool canParse(file_magic magic, StringRef fileExtension
                         const MemoryBuffer &mb) const = 0;
 
   /// \brief Parse a supplied buffer (already filled with the contents of a
@@ -41,9 +41,9 @@ public:
   /// The method is called with:
   /// 1) the file_magic enumeration returned by identify_magic()
-  /// 2) the file extenstion (e.g. ".obj")
+  /// 2) the file extension (e.g. ".obj")
   /// 3) the whole file content buffer if the above is not enough. 





More information about the llvm-commits mailing list